Filter the displayed files by entering a search snippet. Press enter/return to apply filter.

The filter is **case-sensitive** and supports [wildcard syntax](https://support.microsoft.com/en-us/office/examples-of-wildcard-characters-939e153f-bd30-47e4-a763-61897c87b3f4).